GlobalCommand class

A command to run in the working directory

Inheritance

Constructors

GlobalCommand(List<String> args, Future<int> _run(GlobalCommand command, List<Project> projects))
Constructor

Properties

args List<String>
The command to run
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
noFvm bool
If fvm support should be disabled
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silent bool
If output from this command should be displayed
finalinherited
verbose bool
If verbose output should be displayed
no setterinherited

Methods

addArgs(List<String> args) → void
Add arguments to the command
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({required List<Project> projects}) Future<int>
Run the command
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited