ProjectCommand class

A command to run in an individual project

Inheritance

Constructors

ProjectCommand(List<String> args, {bool raw = false, bool parallel = false, Engine? engine})
Constructor

Properties

args → List<String>
The command to run
no setterinherited
engine → Engine?
The engine to use for this command ignoring project config
final
hashCode → int
The hash code for this object.
no setterinherited
noFvm → bool
If fvm support should be disabled
no setterinherited
parallel → bool
Whether to run the command in all projects in parallel
final
raw → bool
Whether to run the command as is
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
silent → bool
If output from this command should be displayed
finalinherited
verbose → bool
If verbose output should be displayed
no setterinherited

Methods

addArgs(List<String> args) → void
Add arguments to the command
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited