PubyConfig class

A puby configuration file

Annotations
  • @immutable

Constructors

PubyConfig.empty()
Create an empty puby config
PubyConfig.fromProjectPath(String path)
Create a puby config from a project path
factory

Properties

excludes → List<String>
Specified command exclusions
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited