Project class

A dart project

Annotations
  • @immutable

Constructors

Project({required Engine engine, required String path, required PubyConfig config, required bool example, required bool hidden, bool exclude = false, required Set<String> dependencies, required bool fvm, required ProjectType type, ProjectType? parentType, required bool workspaceInScope})
Create a Project
const

Properties

config → PubyConfig
The puby config for this project
final
dependencies → Set<String>
All of dependencies for this project including transitive
final
engine → Engine
The engine this project uses
final
example → bool
If this project is an example project
final
exclude → bool
If this project should be excluded from command execution
final
fvm → bool
If this project is configured with FVM
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
If this project is in a hidden folder
final
parentType → ProjectType?
The parent project's type
final
path → String
The relative path to the project
final
prefixArgs → List<String>
The arguments to prefix to any commands run in this project
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ProjectType
The type of project this is
final
workspaceInScope → bool
If this project's workspace is in scope
final

Methods

copyWith({Engine? engine, bool? exclude, bool? fvm}) → Project
Create a copy of this Project with the specified changes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited