ProjectIntermediate class

Intermediate data used during project resolution

Annotations
  • @immutable

Constructors

ProjectIntermediate({required String absolutePath, required String path, required Pubspec pubspec, required ProjectType type})
Constructor
const

Properties

absolutePath → String
The absolute path to the project
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
The relative path to the project
final
pubspec → Pubspec
The parsed pubspec
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ProjectType
The type of project this is
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited