DownloadPackageResult class

Constructors

DownloadPackageResult(PackageId packageId, {required bool didUpdate})

Properties

didUpdate → bool
Whether we had to make changes in the cache in order to download the package.
final
hashCode → int
The hash code for this object.
no setterinherited
packageId → PackageId
The resolved package.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited