pathOfGlobalSnapshot method

String pathOfGlobalSnapshot(
  1. Executable executable
)

The location of the snapshot of the dart program at executable will be stored here.

We use the sdk version to make sure we don't run snapshots from a different sdk.

Implementation

String pathOfGlobalSnapshot(Executable executable) {
  assert(isCachedGlobal);
  return executable.pathOfGlobalSnapshot(workspaceRoot.dir);
}