PackageDetail class

An enum of different levels of detail that can be used when displaying a terse package name.

Constructors

PackageDetail({bool? showVersion, bool? showSource, bool? showDescription})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDescription → bool
Whether to show the package description.
final
showSource → bool?
Whether to show the package source.
final
showVersion → bool?
Whether to show the package version or version range.
final

Methods

max(PackageDetail other) → PackageDetail
Returns a PackageDetail with the maximum amount of detail between this and other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaults → const PackageDetail
The default PackageDetail configuration.