PackageRange class

A reference to a constrained range of versions of one package.

This is represented as a PackageRef and a VersionConstraint.

Constructors

PackageRange(PackageRef _ref, VersionConstraint constraint)
Creates a reference to package with the given name, source, constraint, and description.

Properties

constraint → VersionConstraint
The allowed package versions.
final
description → Description
no setter
hashCode → int
The hash code for this object.
no setteroverride
isRoot → bool
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Source
no setter

Methods

allows(PackageId id) → bool
Whether id satisfies this dependency.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRef() → PackageRef
toString([PackageDetail? detail]) → String
A string representation of this object.
override
withTerseConstraint() → PackageRange
Returns a copy of this with the same semantics, but with a ^-style constraint if possible.

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

root(Package package) → PackageRange
Creates a range that selects the root package.