RepairResult class

The result of repairing a single cache entry.

Constructors

RepairResult(String packageName, Version version, Source source, {required bool success})

Properties

hashCode → int
The hash code for this object.
no setterinherited
packageName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Source
final
success → bool
true if packageName was repaired successfully. false if something failed during the repair.
final
version → Version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited