SolveFailure class

An exception indicating that version solving failed.

Implemented types

Constructors

SolveFailure(Incompatibility incompatibility, {String? suggestions})

Properties

hashCode → int
The hash code for this object.
no setterinherited
incompatibility → Incompatibility
The root incompatibility.
final
message → String
no setter
packageNotFound → PackageNotFoundException?
Returns a PackageNotFoundException that (transitively) caused this failure, or null if it wasn't caused by a PackageNotFoundException.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestions → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Describes how incompatibility was derived, and thus why version solving failed.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited