Command class abstract

A command and it's properties

Implementers

Constructors

Command(List<String> args, {required bool silent})
Constructor

Properties

args List<String>
The command to run
no setter
hashCode int
The hash code for this object.
no setterinherited
noFvm bool
If fvm support should be disabled
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silent bool
If output from this command should be displayed
final
verbose bool
If verbose output should be displayed
no setter

Methods

addArgs(List<String> args) → void
Add arguments to the command
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited